#
# spec file for package zola
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zola
Version:        0.18.0
Release:        1.1
Summary:        Fast static site generator
License:        MIT
URL:            https://github.com/getzola/zola
Source0:        https://github.com/getzola/zola/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  cargo-packaging
BuildRequires:  libgcc_s1
BuildRequires:  pkg-config
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches}

%description
Zola is a static site generator (SSG), similar to Hugo, Pelican, and Jekyll.
It is written in Rust and uses the Tera template engine, which is similar to
Jinja2, Django templates, Liquid, and Twig. Content is written in CommonMark,
a strongly defined, highly compatible specification of Markdown.

%prep
%autosetup -a1 -p1

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%build
%if 0%{?sle_version} == 150400 && 0%{?is_opensuse}
export RUSTC_BOOTSTRAP=1
%endif
%{cargo_build}

%install
%if 0%{?sle_version} == 150400 && 0%{?is_opensuse}
export RUSTC_BOOTSTRAP=1
%endif

%{cargo_install}
export PATH=$PATH:%{buildroot}%{_bindir}
%{name} completion bash | install -Dm 0644 /dev/stdin %{buildroot}%{_datadir}/bash-completion/completions/%{name}.bash
%{name} completion fish | install -Dm 0644 /dev/stdin %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
%{name} completion zsh  | install -Dm 0644 /dev/stdin %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%check
%if 0%{?sle_version} == 150400 && 0%{?is_opensuse}
export RUSTC_BOOTSTRAP=1
%endif
%{cargo_test}

%files
%{_bindir}/zola
%license LICENSE
%doc docs README.md CHANGELOG.md

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/zola.bash

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/zola.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_zola

%changelog
* Tue Dec 19 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove 0001-fix-life-in-zola-serve.patch. Part of 0.18.0 release now.
- Remove cargo_config. Part of vendored tarball now.
- Update to version 0.18.0:
  * update dependencies
  * remove some dummy file
  * fix taxonomies missing lang in sitemap
  * remove code blocks from search index
  * elasticlunr-rs hu language support
* Tue Aug 15 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0001-fix-life-in-zola-serve.patch to address bsc#1214237
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Fri Apr 14 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies
* Mon Mar 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.17.2:
  * Implement Default for LanguageOptions (#2145)
  * Fix tests
  * Update changelog
  * Revert "Allow external links to start with "www.*" (#2100)"
  * Fix index errors (#2129)
  * Fix a page missing from e2e test
  * Update links to tmtheme editor
  * fix: add "slug" where it was forgotten (#2132)
  * installing-and-using-themes.md: Change placeholder format for git repo URL (#2128)
  * installation.md: add Nix installation instructions (#2126)
  * Update Metainfo (#2125)
  * Use default search engine output
* Mon Feb 27 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Increase memory size to fix "Out of memory error" during builds
- Increase disk size to fix "No space left on device" during builds
* Sun Feb 26 2023 socvirnyl.estela@gmail.com
- Update to version 0.17.1:
  * fix `zola serve` not  respecting `preserve_dotfiles_in_output` (#2113)
  * Pass section.generate_feed
  * Fix colocated assets in content directory
  * Fix typo in pages-sections.md (#2115)
- Generate shell completions through zola binary in specfile.
* Sat Feb 18 2023 socvirnyl.estela@gmail.com
- Update to version 0.17.0:
  * Update changelog & test-case
  * Allow external links to start with "www.*" (#2100)
  * Remove println
  * cargo fmt
  * Add test for #1566
  * Downgrade mockito to not raise MSRV
  * Update changelog & mockito
  * feat: External URL redirect (#2080)
  * Page and config authors (#2024) (#2092)
  * Try to disable uninlined format lint
  * Update toml lib
  * Bump Rust CI version
  * clippy
  * Procimage refactor (#2086)
  * Removed faulty Windows-specific path check/conversion. Fixes #2076. (#2088)
  * Errors on empty taxonomies term
  * Filter out temp files or with no extensions from colocated assets
  * Handle pages named index.md in sections
  * Revert "Use reqwest rustls-tls"
  * Remove built-in shortcodes
  * Use reqwest rustls-tls
  * Add plain text syntax alias to text
  * fmt + changelog + updates
  * Reduced cachebust fingerprint to be more reasonable (#2074)
  * Remove code blocks from search index
  * Update changelog
  * Use macro for LanguageOptions::merge
  * Merge default language data with section language data (#2039)
  * Update base64
  * Update changelog
  * Add upgrade guide for Sass
  * libsass -> grass is a breaking change
  * Clippy + 1.63
  * Fmt + change min version
  * Replace libsass by grass
  * Update some deps
  * Expose `markdown` config property to templates (#2052)
  * Add details in the doc on CommonMark extension (#2034)
  * Small update to the docs for get_url (#2033)
  * add preserve_dotfiles_in_output configuration option (#1985)
  * Fix needless_borrow warnings
  * Add clippy to CI
  * markdown: Fix clippy warnings
  * imageproc: Fix clippy warning
  * content: Fix clippy warnings
  * templates: Fix clippy warning
  * Site: fix clippy warnings
  * Fix clippy::manual_retain
  * Fix clippy::derive_partial_eq_without_eq
  * Cargo fmt (#2009)
  * Filter more than 1 footnote in summary (#2017)
  * Search json index (#1998)
  * Do not overfilter HTML when removing footnotes (#2008)
  * Fix no-port-append default
  * Add new flag 'port_append' to give the ability to remove port from base url (#2003)
  * Fix current_url in taxonomy term (#2000)
  * Fix test
  * Minify embedded css and js with additional lib flags (#1922)
  * Update changelog
  * add get_hash function (#1962)
  * Use BufWriter in imageproc (#1996)
  * Handle colocated links to assets
  * Update deps
  * Add flag to override prompt for existing dir (#1986)
  * Tera date-locale feature (#1978)
  * Add sorting by slug (#1926)
  * Simplify taxonomy term struct
  * Get term fn (#1964)
  * Add slugify.paths_keep_dates option. Update docs.
  * Add completion subcommand (#1968)
  * Imporved is_colocated_asset_links (#1972)
  * Metainfo: Add 0.16.1
  * Next version
  * Update `zola-deploy-action` version on docs (#2098)
  * Fix typo
  * document installing via github actions (#2097)
  * Document the render field on taxonomies (#2094)
  * Fix erroring suggestion in docs (#2087)
  * Best way to install Zola on Fedora now is COPR (#2070)
  * Update themes gallery (#2047)
  * docs: rebrand Layer0 to Edgio (#2068)
  * Moved source uwe-arzt.de from github to codeberg (#2062)
  * Fix typos (#2056)
  * documentation: Add pkgsrc. (#1812)
  * Update creating-a-theme.md (#2045)
  * add: more example websites (#2023)
  * Update themes gallery (#2038)
  * Fixed default_language typo (#2040)
  * Update Shortcodes doc to add details on Macros for templates (#2035)
  * Update themes gallery (#2014)
  * update version of zola-deploy-action (#2012)
  * Quotation mark bug fix (#2005)
  * Update themes gallery (#1999)
  * docs: github action version updates (#1977)
  * Update themes gallery (#1971)
* Fri Oct  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Automatic update of vendored dependencies.
* Sun Aug 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- fix specfile. require and supplement bash-completion instead of bash
* Sun Aug 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- add shell completions
- add docs README.md CHANGELOG.md
* Sat Aug 20 2022 socvirnyl.estela@gmail.com
- Update to version 0.16.1:
  * Fix outdated release windows image
  * Update MSRV
  * Last cargo update
  * Strip binary artifact when building for release (#1949)
  * Remove logging
  * The Glob library does not work correctly on windows.  This changes the approach to use the normal WalkDir crate, and the Globset crate instead to find the filter.  This new code correctly compiles sass files across platforms now. (#1950)
  * Update deps
  * parse also *.yml file suffix as YAML; closes #1958 (#1959)
  * Fix overriding built-in shortcodes
* Mon Jul 25 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM
* Wed Jul 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- limit to only Tier 1 support arches
* Tue Jul 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for zola 0.16.0
